# open-terminalui

[![PyPI - Version](https://img.shields.io/pypi/v/open-terminalui.svg)](https://pypi.org/project/open-terminalui)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/open-terminalui.svg)](https://pypi.org/project/open-terminalui)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install open-terminalui
```

## Development

### Installation

```bash
uv sync
```

### Testing

```bash
textual run --dev open_terminalui.entry_points:app
```

In a seperate console
```bash
textual console
```

## License

`open-terminalui` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
